# Pygal_maps_se



- [Pyga_maps_sel](#pygal_maps_se)
    - [Description](#description)
    - [Installation](#installation)
    - [Contribute](#contribute)
    - [Example](#example)
    - [License](#license)

## Description

**pygal_maps_se** is map library for pygal that adds a swedish map.


Find out more about pygal on [www.pygal.org](http://www.pygal.org).


## Installation

As simple as:

```
    $ pip install pygal_maps_se
```


## Example

```
chart = pygal.maps.se.Lan(width=500,height=700)
chart.add('Good places', ['H','BD'])
chart.render()
```


## Contribute

You are welcomed to fork the project and make pull requests.
Be sure to create a branch for each feature.



## License

Copyright © 2020 Jving
LGPLv3:

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
